pub enum AudioHandleErrorKind {
AudioSubsystem,
AudioStream,
InvalidArguments,
}Expand description
A list specifying categories of AudioHandleError error.
Variants
AudioSubsystem
This error occurs when the audio subsystem host or device is not available.
AudioStream
This error occurs while trying to create or modify an audio stream.
InvalidArguments
This error occurs due to the invalid specification of the desired audio parameters or other arguments.