pub struct KempstonMouseDevice { /* private fields */ }Expand description
The Kempston Mouse device implements MouseDevice and MouseInterface traits.
The horizontal position increases when moving to the right and decreases when moving to the left. The vertical position increases when moving from bottom to the top or forward (away from the user) and decreases then moving backward (towards the user).
A horizontal position is being provided when bits of the port address: A8 is 1 and A10 is 0. A vertical position is being provided when bits of the port address: A8 and A10 is 1. A button state is being provided when A8 bit of the port address is 0:
- bit 0 is 0 when the left button is being pressed and 1 when the left button is released.
- bit 1 is 0 when the right button is being pressed and 1 when the right button is released.