UlaFrameCache

Struct UlaFrameCache 

pub struct UlaFrameCache<V> {
    pub frame_pixels: [(u32, [u8; 32]); 192],
    pub frame_colors: [(u32, [u8; 32]); 192],
    pub frame_colors_coarse: [(u32, [u8; 32]); 24],
    /* private fields */
}
Spectrum’s video data frame cache.

When a byte is being written to the video memory and the video beam position has already passed the referenced screen cell, the cell value is being cached from memory before the data in memory is being modified.

The caching is performed only once per frame for each potential cell so subsequent writes to the same memory address won’t modify the cached cell value.

When a screen is being drawn the data stored in cache will override any value currently residing in video memory.

Fields

frame_pixels: [(u32, [u8; 32]); 192]frame_colors: [(u32, [u8; 32]); 192]frame_colors_coarse: [(u32, [u8; 32]); 24]

Implementations

Source

impl<V> UlaFrameCache<V>

pub fn clear(&mut self)

Source

impl<V: VideoFrame> UlaFrameCache<V>

pub fn update_frame_pixels<M: ZxMemory>( &mut self, memory: &M, _: CellCoords, addr: u16, ts: VideoTs, )

Compares the given bitmap cell coordinates with the video timestamp and depending on the result of that comparison caches (or not) the bitmap cell with the value from the memory at the given address.

pub fn update_frame_colors<M: ZxMemory>( &mut self, memory: &M, _: CellCoords, addr: u16, ts: VideoTs, )

Compares the given attribute cell coordinates with the video timestamp and depending on the result of that comparison caches (or not) the attribute cell or cells with the value from the memory at the given address.

pub fn apply_snow_interference( &mut self, screen: &ScreenArray, _: CellCoords, snow: u8, )

Caches the bitmap and attribute cell at the given coordinates with the snow distortion applied.