pub struct MultiJoystickBusDevice<D> {
pub joystick: JoystickSelect,
/* private fields */
}Expand description
A selectable joystick controller, providing a BusDevice implementation.
This controller allows changing the implementation of the joystick device at run time.
Fields
joystick: JoystickSelectImplementations
Sourceimpl<D> MultiJoystickBusDevice<D>where
D: Default,
impl<D> MultiJoystickBusDevice<D>where
D: Default,
pub fn new_with(joystick: JoystickSelect) -> MultiJoystickBusDevice<D>
Methods from Deref<Target = JoystickSelect>
pub const MAX_GLOBAL_INDEX: usize = 4usize
Sourcepub fn joystick_interface(
&mut self,
index: usize,
) -> Option<&mut (dyn JoystickInterface + 'static)>
pub fn joystick_interface( &mut self, index: usize, ) -> Option<&mut (dyn JoystickInterface + 'static)>
Provides a mutable reference to the selected joystick type via a dynamic trait.
Some variants contain more than one joystick, so provide an appropriate index to
select one of them.
Returns None if a joystick with the given index doesn’t exist.
Sourcepub fn select_next_joystick(&mut self, index: usize) -> usize
pub fn select_next_joystick(&mut self, index: usize) -> usize
Returns an index of the next joystick in the current variant.
Optionally changes the current joystick device variant to the next one cyclically.
Some variants contain more than one joystick, provide an appropriate index to
select one of them. If index + 1 exceeds the number of joysticks available then
the next variant is being selected.
pub fn is_last(&self) -> bool
pub fn is_kempston(&self) -> bool
pub fn is_fuller(&self) -> bool
pub fn is_sinclair(&self) -> bool
pub fn is_cursor(&self) -> bool